/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2006 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id: $
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common;

import java.util.Properties;


/**
 * This class contains all configuration parameters needed by the component.
 *
 * @version $Revision: $ $Date: $
 * @since Petals CDK 1.5
 * @author ofabre EBM Websourcing
 */
public class ComponentConfiguration {

    /**
     * The thread pool size.
     */
    private int poolSize = 50;

    /**
     * Type of message exchange ignored.
     */
    private IgnoredStatusConstants ignoredStatus;

    /**
     * The JBI Listener component implementation class name
     */
    private String jbiListenerClassName;

    /**
     * The External Listener component implementation class name
     */
    private String externalListenerClassName;

    /**
     * Performance notifications enabled ?
     */
    private boolean performanceNotificationsEnabled = false;

    /**
     * Performance notifications step
     */
    private int performanceNotificationsStep = 1;

    private Properties properties;

    /**
     * Creates a new instance of {@link ComponentConfiguration}
     *
     */
    public ComponentConfiguration() {
        properties = new Properties();
    }

    public IgnoredStatusConstants getIgnoredStatus() {
        return ignoredStatus;
    }

    public void setIgnoredStatus(IgnoredStatusConstants ignoredStatus) {
        this.ignoredStatus = ignoredStatus;
    }

    public int getPoolSize() {
        return poolSize;
    }

    public void setPoolSize(int poolSize) {
        this.poolSize = poolSize;
    }

    public String getExternalListenerClassName() {
        return externalListenerClassName;
    }

    public void setExternalListenerClassName(String externalListenerClassName) {
        this.externalListenerClassName = externalListenerClassName;
    }

    public String getJbiListenerClassName() {
        return jbiListenerClassName;
    }

    public void setJbiListenerClassName(String jbiListenerClassName) {
        this.jbiListenerClassName = jbiListenerClassName;
    }

	public boolean isPerformanceNotificationsEnabled() {
		return performanceNotificationsEnabled;
	}

	public void setPerformanceNotificationsEnabled(
			boolean performanceNotificationsEnabled) {
		this.performanceNotificationsEnabled = performanceNotificationsEnabled;
	}

	public int getPerformanceNotificationsStep() {
		return performanceNotificationsStep;
	}

	public void setPerformanceNotificationsStep(int performanceNotificationsStep) {
		this.performanceNotificationsStep = performanceNotificationsStep;
	}

    /**
     * @return the additionalProperties
     */
    public Properties getProperties() {
        return this.properties;
    }

    /**
     * @param additionalProperties the additionalProperties to set
     */
    public void setProperties(Properties properties) {
        this.properties = properties;
    }
}
