/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common.interceptor.impl;

import java.io.File;
import java.io.IOException;
import java.util.Map;
import java.util.StringTokenizer;

import org.objectweb.petals.component.common.interceptor.Interceptor;
import org.objectweb.petals.component.common.util.MessageExchangeWrapper;
import org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement;

/**
 * Run a system script on message interception. The interceptor is configured in
 * the SU extensions like this :
 *
 * <pre>
 * &lt;interceptor name=&quot;&quot; command=&quot;YOURSCRIPT&quot; args=&quot;BLANK SEPARATED ARGS&quot; dir=&quot;THE EXECUTION DIRECTORY&quot;/&gt;
 * </pre>
 *
 * Where name is the name of the interceptor, <b>command</b> is the command to
 * run (must be in the path if it is not absolute), <b>args</b> are the program
 * arguments separated by spaces (like 'arg1 arg2 arg3', and <b>dir</b> is the
 * directory to launch the program from.
 *
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 *
 */
public class SystemExecInterceptor extends Interceptor {

    public static final String COMMAND = "command";

    public static final String ARGS = "args";

    public static final String DIR = "dir";

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.component.common.interceptor.Interceptor#handleMessageAccept(javax.jbi.messaging.MessageExchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageAccept(MessageExchangeWrapper mex,
            ServiceUnitExtensibleElement consumeProvide,
            Map<String, String> additionalParameters) {
        systemExec(additionalParameters);
    }

    /*
     * (non-Javadoc)
     *
     * @see org.objectweb.petals.component.common.interceptor.Interceptor#handleMessageSent(javax.jbi.messaging.MessageExchange,
     *      org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement,
     *      java.util.Map)
     */
    @Override
    public void handleMessageSent(MessageExchangeWrapper mex,
            ServiceUnitExtensibleElement consumeProvide,
            Map<String, String> additionalParameters) {
        systemExec(additionalParameters);
    }

    /**
     * Runs a system script
     *
     * @param additionalParameters
     */
    protected void systemExec(Map<String, String> additionalParameters) {
        String command = additionalParameters.get(COMMAND);
        if (command == null) {
            logger
                    .warning("Can not execute a script since its name is not defined in the interceptor properties");
            return;
        }

        // get the args
        String args = additionalParameters.get(ARGS);
        String[] envp = null;
        if (args != null) {
            StringTokenizer tokenizer = new StringTokenizer(args);
            envp = new String[tokenizer.countTokens()];
            int i = 0;
            while (tokenizer.hasMoreElements()) {
                envp[i++] = (String) tokenizer.nextElement();
            }
        }

        // get the file
        String fileName = additionalParameters.get(DIR);
        File dir = null;
        if (fileName != null) {
            dir = new File(fileName);
        }

        try {
            Runtime.getRuntime().exec(command, envp, dir);
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

}
