/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common.listener;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.logging.Logger;

import org.objectweb.petals.component.common.AbstractComponent;
import org.objectweb.petals.component.common.interceptor.Interceptor;
import org.objectweb.petals.component.common.interceptor.MessageInterceptorManager;
import org.objectweb.petals.component.common.interceptor.description.InterceptorConfiguration;
import org.objectweb.petals.component.common.su.ServiceUnitDataHandler;
import org.objectweb.petals.component.common.su.ServiceUnitManager;
import org.objectweb.petals.component.common.util.MessageExchangeWrapper;
import org.objectweb.petals.jbi.descriptor.ServiceUnitExtensibleElement;

/**
 * @author Christophe HAMERLING (chamerling) - eBM WebSourcing
 *
 */
public class MessageInterceptorProcessor {

    enum Phase {
        SEND, RECEIVE;
    }

    private static final Map<String, String> EMPTY_PARAMETERS = new HashMap<String, String>();

    protected AbstractComponent component;

    protected Logger logger;

    /**
     * Creates a new instance of {@link MessageInterceptorProcessor}
     *
     */
    public MessageInterceptorProcessor(AbstractComponent component,
            Logger logger) {
        this.component = component;
        this.logger = logger;
    }

    // /**
    // * Intercept a message
    // *
    // * @param mex
    // * @param consumeProvide
    // */
    // protected final void intercept(MessageExchange mex,
    // ServiceUnitExtensibleElement consumeProvide, Mode mode)
    // throws PEtALSCDKException {
    // if (mode == Mode.IN_OUT) {
    // throw new PEtALSCDKException("Unsupported mode " + mode);
    // }
    //
    // try {
    // this.onIntercept(mex);
    // } catch (Exception e) {
    // throw new PEtALSCDKException(e);
    // }
    //
    // if (this.mode == Mode.IN_OUT || this.mode == mode) {
    // if (mode == Mode.IN) {
    // acceptMessageIntercept(mex, consumeProvide);
    // } else if (mode == Mode.OUT) {
    // sendMessageIntercept(mex, consumeProvide);
    // }
    // } else {
    // logger.log(Level.WARNING, "Bad mode, can not intercept message");
    // }
    // }

    /**
     *
     * @param messageExchange
     * @param extensible
     */
    public void intercept(final MessageExchangeWrapper messageExchange,
            final ServiceUnitExtensibleElement extensible, final Phase phase) {
        logger.fine("Intercepting message processing on " + phase);

        ServiceUnitManager suManager = (ServiceUnitManager) component
                .getServiceUnitManager();
        ServiceUnitDataHandler dataHandler = suManager
                .getSuDataHandlerForConsumeProvide(extensible);

        if (dataHandler != null) { // no DH when no deployed SU
            MessageInterceptorManager messageInterceptorManager = dataHandler
                    .getMessageInterceptorManager(extensible);

            if (messageInterceptorManager != null) {
                this.intercept(messageExchange, extensible,
                        messageInterceptorManager, phase);
            }
        }
    }

    /**
     *
     * @param messageExchange
     * @param extensible
     * @param messageInterceptorManager
     */
    protected void intercept(MessageExchangeWrapper messageExchange,
            ServiceUnitExtensibleElement extensible,
            MessageInterceptorManager messageInterceptorManager, Phase phase) {
        Map<String, Interceptor> interceptors = null;
        Map<String, InterceptorConfiguration> additionalConfiguration = null;

        if (messageInterceptorManager != null) {

            // getting good interceptors
            if (phase == Phase.RECEIVE) {
                interceptors = messageInterceptorManager
                        .getInputOrderedInterceptors();
                additionalConfiguration = messageInterceptorManager
                        .getInputAdditionalConfiguration();
            } else if (phase == Phase.SEND) {
                interceptors = messageInterceptorManager
                        .getOutputOrderedInterceptors();
                additionalConfiguration = messageInterceptorManager
                        .getOutputAdditionalConfiguration();
            }

            Iterator<String> iterator = interceptors.keySet().iterator();
            while (iterator.hasNext()) {
                String interceptorName = iterator.next();

                // get interceptor
                Interceptor interceptor = interceptors.get(interceptorName);

                // get additional configuration from consume/provide
                InterceptorConfiguration configuration = additionalConfiguration
                        .get(interceptorName);
                Map<String, String> parameters = null;
                if (configuration != null) {
                    parameters = configuration.getParameters();
                } else {
                    // empty
                    parameters = EMPTY_PARAMETERS;
                }

                // intercept
                if (phase == Phase.RECEIVE) {
                    interceptor.handleMessageAccept(messageExchange,
                            extensible, parameters);
                } else if (phase == Phase.SEND) {
                    interceptor.handleMessageSent(messageExchange, extensible,
                            parameters);
                } else {

                }
            }

        } else {
            logger.warning("No interceptor manager has been found");
        }
    }
}
