/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common.mbean;

import javax.jbi.messaging.MessageExchange;


/**
 * This class describes the data of a performance notification.
 *
 * @author Christophe DENEUX - Capgemini Sud
 *
 */

public final class PerformanceNotification {
	
	public static final String RECEIVING_FROM_NMR = "RECEIVING_FROM_NMR";
	public static final String SENDING_TO_NMR = "SENDING_TO_NMR";
	public static final String RECEIVING_FROM_OUTSIDE = "RECEIVING_FROM_OUTSIDE";
	public static final String SENDING_TO_OUTSIDE = "SENDING_TO_OUTSIDE";

	// time-stamp of the processing beginning.
	long timestamp = 0;
	
	// processing duration in milliseconds
	long duration = 0;
	
	// processor
	String owner = null;
	
	// notification type
	String type = null;
	
	// user data
	String userData = null;
	
	// global seq num
	long globalSeqNum = 0;
    
    // uid
    String uid = null;
	
	public PerformanceNotification(final long start, final String owner,
            final String type, final String userData, final long globalSeqNum,
            final String uid) {
        this.timestamp = start;
        this.owner = owner;
        this.type = type;
        this.userData = userData;
        this.globalSeqNum = globalSeqNum;
        this.uid = uid;
    }
	
	public final void end() {
		this.duration = System.currentTimeMillis() - this.timestamp;
	}

	public long getTimestamp() {
		return this.timestamp;
	}

	public long getDuration() {
		return this.duration;
	}

	public String getOwner() {
		return this.owner;
	}

	public String getType() {
		return this.type;
	}

    public String getUserData() {
        return this.userData;
    }

    public long getGlobalSeqNum() {
        return this.globalSeqNum;
    }

    public String getUID() {
        return this.uid;
    }
    
    public final void setUIDInMessageExchange(MessageExchange exchange) {
        exchange.setProperty(PerformanceNotifierMBean.PERF_NOTIF_NMR_MSG_ATTR, this.uid);
    }
}
