/**
 * PETALS - PETALS Services Platform.
 * Copyright (c) 2007
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -------------------------------------------------------------------------
 * $Id$
 * -------------------------------------------------------------------------
 */

package org.objectweb.petals.component.common.mbean;


/**
 * This class describes a performance notification counter.
 *
 * @author Christophe DENEUX - Capgemini Sud
 *
 */

public final class PerformanceNotificationCounter {
	
    private static final short RECEIVING_FROM_NMR_IDX = 0;
    private static final short SENDING_TO_NMR_IDX = 1;
    private static final short RECEIVING_FROM_OUTSIDE_IDX = 2;
    private static final short SENDING_TO_OUTSIDE_IDX = 3;

    private long[] seqNum = {0, 0, 0, 0};
    
    private long step = 0;

    public PerformanceNotificationCounter(final long step) {
        this.step = step;
    }
    
	private short getTypeNotif(final String pTypeNotif) {

        short typeNotif = RECEIVING_FROM_NMR_IDX;
        if (PerformanceNotification.RECEIVING_FROM_OUTSIDE.equals(pTypeNotif)) {
            typeNotif = RECEIVING_FROM_OUTSIDE_IDX;
        }
        else if (PerformanceNotification.SENDING_TO_NMR.equals(pTypeNotif)) {
            typeNotif = SENDING_TO_NMR_IDX;
        }
        else if (PerformanceNotification.SENDING_TO_OUTSIDE.equals(pTypeNotif)) {
            typeNotif = SENDING_TO_OUTSIDE_IDX;
        }
        
        return typeNotif;
	}
	
	public final boolean inc(final String pTypeNotif) {
	    short typeNotif = this.getTypeNotif(pTypeNotif);
	    boolean bRet = false;
	    
	    synchronized (seqNum) {
	        if (++seqNum[typeNotif] == step) {
	            seqNum[typeNotif] = 0;
	            bRet = true;
	        }
	    }
	    
	    return bRet; 
	}

    public long getStep() {
        return step;
    }

    public void setStep(long step) {
        this.step = step;
        
        synchronized (seqNum) {
            for (int i=0; i<4; i++) {
                if (seqNum[i] >= this.step) {
                    seqNum[i] = 0;
                }
            }
        }
    }
}
